#######################
Mathematical Background
#######################

This section explains the mathematical concepts on which ODL is built.

.. toctree::
    :maxdepth: 2

    linear_spaces
    discretization
    resizing_ops
    derivatives_guide
    trafos/index
    solvers/solvers
